@@ -1,12 +1,25 @@
 use strict;
 use warnings;
-package Exception::Reporter::Summarizer::Catalyst;
-{
-  $Exception::Reporter::Summarizer::Catalyst::VERSION = '0.004';
-}
+package Exception::Reporter::Summarizer::Catalyst 0.005;
 use parent 'Exception::Reporter::Summarizer';
 # ABSTRACT: a summarizer for Catalyst applications
 
+#pod =head1 OVERVIEW
+#pod
+#pod If added as a summarizer to an L<Exception::Reporter>, this plugin will
+#pod summarize Catalyst objects, adding summaries for the request, stash, errors,
+#pod user, and session.
+#pod
+#pod =attr resolve_hostname
+#pod
+#pod If true, the summary will include the hostname of the remote client.  Catalyst
+#pod I<always> resolves this hostname the first time it's requested and I<never>
+#pod accepts it from the server.  That means it might be slow.
+#pod
+#pod Right now, this defaults to true.  It might default to false later.  Consider
+#pod being explicit if you're concerned about this behavior.
+#pod
+#pod =cut
 
 use Try::Tiny;
 
@@ -146,13 +159,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Exception::Reporter::Summarizer::Catalyst - a summarizer for Catalyst applications
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 OVERVIEW
 
@@ -160,6 +175,18 @@ If added as a summarizer to an L<Exception::Reporter>, this plugin will
 summarize Catalyst objects, adding summaries for the request, stash, errors,
 user, and session.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 resolve_hostname
@@ -173,7 +200,23 @@ being explicit if you're concerned about this behavior.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
+
+=head1 CONTRIBUTORS
+
+=for stopwords fREW Schmidt Ricardo Signes
+
+=over 4
+
+=item *
+
+fREW Schmidt <frioux@gmail.com>
+
+=item *
+
+Ricardo Signes <rjbs@semiotic.systems>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
